//  Created by Sir Cheshire

#import "ImgDownload.h"

@interface ImgDownload()
@property (nonatomic, retain) NSMutableData *receivedData;
@end

@implementation ImgDownload
@synthesize urlString;
@synthesize image;
@synthesize delegate;
@synthesize receivedData;

#pragma mark -

- (UIImage *)image
{
    if (image == nil && !downloading)
    {
        if (urlString != nil && [urlString length] > 0)
        {
            NSURLRequest *req = [[NSURLRequest alloc] initWithURL:[NSURL URLWithString:self.urlString]];
            NSURLConnection *con = [[NSURLConnection alloc] 
                                    initWithRequest:req 
                                    delegate:self 
                                    startImmediately:NO];
            
            [con scheduleInRunLoop:[NSRunLoop currentRunLoop] forMode:NSRunLoopCommonModes];
            [con start];

            if (con) 
            {
                NSMutableData *data = [[NSMutableData alloc] init];
                self.receivedData=data;
            } 
            else 
            {
                NSError *error = [NSError errorWithDomain:ImgDownloadErrorDomain code:ImgDownloadErrorNoConnection userInfo:nil];
                if ([self.delegate respondsToSelector:@selector(download:didFailWithError:)])
                    [delegate download:self didFailWithError:error];
            }    
            downloading = YES;
        }
    }
    return image;
}

#pragma mark -
#pragma mark NSURLConnection Callbacks
- (void)connection:(NSURLConnection *)connection didReceiveResponse:(NSURLResponse *)response 
{
    [receivedData setLength:0];
}
- (void)connection:(NSURLConnection *)connection didReceiveData:(NSData *)data 
{
    [receivedData appendData:data];
}
- (void)connection:(NSURLConnection *)connection
  didFailWithError:(NSError *)error 
{
  
    if ([delegate respondsToSelector:@selector(download:didFailWithError:)])
        [delegate download:self didFailWithError:error];
}
- (void)connectionDidFinishLoading:(NSURLConnection *)connection 
{
    
    
    self.image = [UIImage imageWithData:receivedData];
    if ([delegate respondsToSelector:@selector(downloadDidFinishDownloading:)])
        [delegate downloadDidFinishDownloading:self];
    
    
        self.receivedData = nil;
}
#pragma mark -
#pragma mark Comparison

@end
